<?php

/**
 * @file
 * Browser report for the visitors module.
 */

/**
 * Get data for browser report order the query based on a header array.
 *
 * @param header
 *   Table header array. If header is NULL - data is not sorted.
 *
 * @return
 *   Browsers data array
 */
function visitors_browser_data($header) {
  $query = db_select('visitors', 'v');
  $query->addExpression('COUNT(*)', 'count');
  $query->innerJoin(
    'visitors_browscap',
    'vb',
    'v.visitors_user_agent=vb.user_agent'
  );
  $query->fields('vb', array('comment'));
  visitors_date_filter_sql_condition($query);
  $query->groupBy('comment');

  if (!is_null($header)) {
    $query->extend('TableSort')->orderByHeader($header);
  }

  return $query->execute();
}

/**
 * Display browser report.
 *
 * @return
 *   string browser report html source
 */
function visitors_browser() {
  $header = array(
    array('data' => t('#')),
    array(
      'data' => t('Browser'),
      'field' => 'comment',
    ),
    array(
      'data' => t('Pages'),
      'field' => 'count',
      'sort' => 'desc'
    ),
    array('data' => t('%')),
  );

  $hits_count = visitors_get_hits_count();
  $results = visitors_browser_data($header);
  $rows = array();
  $i = 0;
  $count = 0;

  foreach ($results as $data) {
    $rows[] = array(
      ++$i,
      $data->comment,
      $data->count,
      round($data->count / $hits_count * 100, 3)
    );
    $count += $data->count;
  }

  $output  = visitors_date_filter();

  if (count($rows) > 1) {
    $output .= sprintf(
      '<img src="%s" alt="%s">',
      url('visitors/browser/chart'),
      t('Browser')
    );
  }

  $output .= theme('table', array('header' => $header, 'rows' => $rows));

  return $output;
}

/**
 * Display browser chart report.
 */
function chart_visitors_browser() {
  $results  = visitors_browser_data(NULL);
  $tmp_rows = array();
  $rows     = array();

  foreach ($results as $data) {
    $rows[$data->comment] = $data->count;
  }

  $platforms = array_unique(array_keys($rows));
  visitors_chart($rows, $platforms);
}

